@@ -18,7 +18,7 @@ def construct_metadata_file_1_2(metadata, extra_dependencies=()):
     https://peps.python.org/pep-0345/
     """
     metadata_file = 'Metadata-Version: 1.2\n'
-    metadata_file += f'Name: {metadata.core.name}\n'
+    metadata_file += f'Name: {metadata.core.raw_name}\n'
     metadata_file += f'Version: {metadata.version}\n'
 
     if metadata.core.description:
@@ -77,7 +77,7 @@ def construct_metadata_file_2_1(metadata, extra_dependencies=()):
     https://peps.python.org/pep-0566/
     """
     metadata_file = 'Metadata-Version: 2.1\n'
-    metadata_file += f'Name: {metadata.core.name}\n'
+    metadata_file += f'Name: {metadata.core.raw_name}\n'
     metadata_file += f'Version: {metadata.version}\n'
 
     if metadata.core.description:
@@ -110,6 +110,10 @@ def construct_metadata_file_2_1(metadata, extra_dependencies=()):
             else:
                 metadata_file += f'{indent}{line}\n'
 
+    if metadata.core.license_files:
+        for license_file in metadata.core.license_files:
+            metadata_file += f'License-File: {license_file}\n'
+
     if metadata.core.keywords:
         metadata_file += f"Keywords: {','.join(metadata.core.keywords)}\n"
 
@@ -149,7 +153,7 @@ def construct_metadata_file_2_2(metadata, extra_dependencies=()):
     https://peps.python.org/pep-0643/
     """
     metadata_file = 'Metadata-Version: 2.2\n'
-    metadata_file += f'Name: {metadata.core.name}\n'
+    metadata_file += f'Name: {metadata.core.raw_name}\n'
     metadata_file += f'Version: {metadata.version}\n'
 
     if metadata.core.description:
@@ -182,6 +186,10 @@ def construct_metadata_file_2_2(metadata, extra_dependencies=()):
             else:
                 metadata_file += f'{indent}{line}\n'
 
+    if metadata.core.license_files:
+        for license_file in metadata.core.license_files:
+            metadata_file += f'License-File: {license_file}\n'
+
     if metadata.core.keywords:
         metadata_file += f"Keywords: {','.join(metadata.core.keywords)}\n"
 
@@ -221,7 +229,7 @@ def construct_metadata_file_2_3(metadata, extra_dependencies=()):
     https://peps.python.org/pep-0639/
     """
     metadata_file = 'Metadata-Version: 2.3\n'
-    metadata_file += f'Name: {metadata.core.name}\n'
+    metadata_file += f'Name: {metadata.core.raw_name}\n'
     metadata_file += f'Version: {metadata.version}\n'
 
     if metadata.core.description:
